# Employees
A list of employees for the selected company. For more details on how to add/delete employees see section "Buttons".

## Columns:
Each column title has three lines on the right if you hover over it. Click on them to show options for that column. The second tab of the options menu will allow you to filter the column, the third to completely hide entire columns. Click on anywhere else on the column to order it, cycling between ascending, descending and no ordering. Hold shift while clicking to order multiple columns with individual weights.

### Name:
The employee's first and last name.

### Position:
The position of the employee within his company. Positions can be added, edited and deleted by managers under CRM > Administration > Company Positions.

### Primary Relationship Manager:
Displays the primary relationship manager of the employee. Hover over the name to display more information about the person.

### Primary Telephone:
The employee's primary telephone number.

### Primary Email:
Primary email address of the employee.

## Legend:
Click on the legend to filter for employees where the selected company is their primary employer.

## Buttons:
To add employees to the company the person needs to already exist in the database. Use the custom button labeled "New Person" at the top of the list if you need to create a new person and return to this view. Now you are able to add the person to the company by pressing the green plus button. Deleting an employee (but not the person) can be achieved by using the trash button at the end of the row if the company is a) not the employee's primary employer or b) the employee's only employer. If the employee has several employers you need to first make one of the other employers primary to be able to see the delete button. The button below the trash icon shwowing a group of persons can be used to modify the relationship, e.g. make it primary or modify the employee's position within the company.

## Filters:

### No Activity:
Filter employees with no activity for x amount of time.

## Search Field:
Typing in the search field allows to filter the employees by name.
